==> jc-1.4.0.tar.gz: gnu/java/rmi/registry/RegistryImpl__5fStub.h <==
// public final class gnu.java.rmi.registry.RegistryImpl_Stub

// class file dependencies
// @dep_class c8eec05439029a7d gnu_java_rmi_registry_RegistryImpl__5fStub
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteStub

#include "java/rmi/server/RemoteStub.h"

#ifndef _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_
#define _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RemoteRef$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object;

typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct {
	struct _jc_java_lang_reflect_Method$object	*__24method__5fbind__5f0;
	struct _jc_java_lang_reflect_Method$object	*__24method__5flist__5f1;
	struct _jc_java_lang_reflect_Method$object	*__24method__5flookup__5f2;
	struct _jc_java_lang_reflect_Method$object	*__24method__5frebind__5f3;
	struct _jc_java_lang_reflect_Method$object	*__24method__5funbind__5f4;
	struct _jc_java_lang_Class$object	*array__24Ljava__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24registry__24RegistryImpl;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24Method;
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24Remote;
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24RemoteRef;
	_jc_object_array	*operations;
	jlong	interfaceHash;
	jlong	serialVersionUID;
	jboolean	useNewInvoke;
};
extern _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$bind$251a9c112e05991e(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern _jc_object_array *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$list$9e09da44f0278aa5(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *);
extern struct _jc_object *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$rebind$082655182723d0d0(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$bind$251a9c112e05991e;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$list$9e09da44f0278aa5;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$lookup$c76567b1fb804127;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$rebind$082655182723d0d0;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$unbind$6f23bcd0c5499698;

// Static methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods {
	void	(*bind$251a9c112e05991e)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	_jc_object_array	*(*list$9e09da44f0278aa5)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *);
	struct _jc_object	*(*lookup$c76567b1fb804127)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *);
	void	(*rebind$082655182723d0d0)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*unbind$6f23bcd0c5499698)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods	gnu_java_rmi_registry_RegistryImpl__5fStub;
};

// Vtype
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs {
    _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs	gnu_java_rmi_registry_RegistryImpl__5fStub;
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
    _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs	gnu_java_rmi_registry_RegistryImpl__5fStub;
};

// Object instance structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object {
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype	*vtype;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_registry_RegistryImpl__5fStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$class_object;

#endif	/* _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/registry/RegistryImpl__5fStub.h <==
// public final class gnu.java.rmi.registry.RegistryImpl_Stub

// class file dependencies
// @dep_class c8eec05439029a7d gnu_java_rmi_registry_RegistryImpl__5fStub
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteStub

#include "java/rmi/server/RemoteStub.h"

#ifndef _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_
#define _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RemoteRef$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object;

typedef struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct {
	struct _jc_java_lang_reflect_Method$object	*__24method__5fbind__5f0;
	struct _jc_java_lang_reflect_Method$object	*__24method__5flist__5f1;
	struct _jc_java_lang_reflect_Method$object	*__24method__5flookup__5f2;
	struct _jc_java_lang_reflect_Method$object	*__24method__5frebind__5f3;
	struct _jc_java_lang_reflect_Method$object	*__24method__5funbind__5f4;
	struct _jc_java_lang_Class$object	*array__24Ljava__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24registry__24RegistryImpl;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24Method;
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24Remote;
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24RemoteRef;
	_jc_object_array	*operations;
	jlong	interfaceHash;
	jlong	serialVersionUID;
	jboolean	useNewInvoke;
};
extern _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$fields_struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$bind$251a9c112e05991e(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$list$9e09da44f0278aa5(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$rebind$082655182723d0d0(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$bind$251a9c112e05991e;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$list$9e09da44f0278aa5;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$lookup$c76567b1fb804127;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$rebind$082655182723d0d0;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method_info$unbind$6f23bcd0c5499698;

// Static methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods {
	void	(*bind$251a9c112e05991e)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*list$9e09da44f0278aa5)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*lookup$c76567b1fb804127)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*rebind$082655182723d0d0)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*unbind$6f23bcd0c5499698)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vmethods	gnu_java_rmi_registry_RegistryImpl__5fStub;
};

// Vtype
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs {
    _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_refs	gnu_java_rmi_registry_RegistryImpl__5fStub;
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
    _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$sub_nonrefs	gnu_java_rmi_registry_RegistryImpl__5fStub;
};

// Object instance structure
struct _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$object {
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype	*vtype;
	_jc_gnu_java_rmi_registry_RegistryImpl__5fStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$vtype _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_registry_RegistryImpl__5fStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_registry_RegistryImpl__5fStub$class_object;

#endif	/* _JC_gnu_java_rmi_registry_RegistryImpl__5fStub_H_ */
